@@ -59,6 +59,7 @@
 #' icci(fit1, fit2)
 #' }
 #'
+#' @importFrom stats AIC var qnorm
 #' @export
 icci <- function(object1, object2, conf.level=.95) {
   classA <- class(object1)[1L]
@@ -109,12 +110,16 @@ icci <- function(object1, object2, conf.level=.95) {
 print.icci <- function(x, ...) {
   cat("\nModel 1 \n")
   cat(" Class:", x$class$class1, "\n")
-  cat(" Call:", deparse(x$call$call1, nlines=1), fill=TRUE)
+  ## a char vector with each element of length 'width.cutoff'
+  model1call <- deparse(x$call$call1)
+  cat(" Call: ", model1call[1], if (length(model1call) > 1) "...\n" else "\n", sep="")
   cat(" AIC:", formatC(x$AIC$AIC1, digits=3L, format="f"), "\n")
   cat(" BIC:", formatC(x$BIC$BIC1, digits=3L, format="f"), "\n")
-  cat("Model 2 \n")
+  cat("\nModel 2 \n")
   cat(" Class:", x$class$class2, "\n")
-  cat(" Call:", deparse(x$call$call2, nlines=1), "\n", fill=TRUE)
+  ## a char vector with each element of length 'width.cutoff'
+  model2call <- deparse(x$call$call2)
+  cat(" Call: ", model2call[1], if (length(model2call) > 1) "...\n" else "\n", sep="")
   cat(" AIC:", formatC(x$AIC$AIC2, digits=3L, format="f"), "\n")
   cat(" BIC:", formatC(x$BIC$BIC2, digits=3L, format="f"), "\n\n")
 
